# This module is provided for backwards compatibility with
# googleapis-common-protos <= 1.52.0, where this import path contained
# all of the message and gRPC definitions.

from google.longrunning.operations_proto_pb2 import *
from google.longrunning.operations_pb2_grpc import *
